@@ -7,7 +7,11 @@ import matplotlib.transforms
 import numpy as np
 import spiceypy as spice
 from matplotlib.axes import Axes
-from spiceypy.utils.exceptions import NotFoundError, SpiceKERNELVARNOTFOUND
+from spiceypy.utils.exceptions import (
+    NotFoundError,
+    SpiceKERNELVARNOTFOUND,
+    SpiceSPKINSUFFDATA,
+)
 
 from . import data_loader, utils
 from .base import SpiceBase, Numeric
@@ -105,10 +109,10 @@ class Body(SpiceBase):
         """Distance from the target to the observer at the time of the observation."""
         self.target_ra: float
         """Right ascension (RA) of the target centre."""
-        self.target_diameter_arcsec: float
-        """Equatorial angular diameter of the target in arcseconds."""
         self.target_dec: float
         """Declination (Dec) of the target centre."""
+        self.target_diameter_arcsec: float
+        """Equatorial angular diameter of the target in arcseconds."""
         self.subpoint_distance: float
         """Distance from the observer to the sub-observer point on the target."""
         self.subpoint_lon: float
@@ -187,7 +191,6 @@ class Body(SpiceBase):
             # convert input datetime to UTC, then to a string compatible with spice
             utc = utc.replace(tzinfo=datetime.timezone.utc)
             utc = utc.strftime(self._DEFAULT_DTM_FORMAT_STRING)
-        self.utc = utc
 
         self.target = self.standardise_body_name(target)
         self.observer = self.standardise_body_name(observer)
@@ -209,8 +212,9 @@ class Body(SpiceBase):
         self._surface_method_encoded = self._encode_str(self.surface_method)
 
         # Get target properties and state
-        self.et = spice.utc2et(self.utc)
+        self.et = spice.utc2et(utc)
         self.dtm: datetime.datetime = self.et2dtm(self.et)
+        self.utc = self.dtm.strftime(self._DEFAULT_DTM_FORMAT_STRING)
         self.target_body_id: int = spice.bodn2c(self.target)
         self.target_frame = 'IAU_' + self.target
         self._target_frame_encoded = self._encode_str(self.target_frame)
@@ -305,7 +309,20 @@ class Body(SpiceBase):
                     self.ring_radii.add(r)
 
     def __repr__(self) -> str:
-        return f'Body({self.target!r}, {self.utc!r})'
+        return f'Body({self.target!r}, {self.utc!r}, observer={self.observer!r})'
+
+    def _get_equality_tuple(self) -> tuple:
+        return (
+            self.target,
+            self.utc,
+            self.observer,
+            self.observer_frame,
+            self.illumination_source,
+            self.aberration_correction,
+            self.subpoint_method,
+            self.surface_method,
+            super()._get_equality_tuple(),
+        )
 
     def create_other_body(
         self, other_target: str | int, fallback_to_basic_body: bool = True
@@ -386,7 +403,9 @@ class Body(SpiceBase):
         for other_target in other_targets:
             self.other_bodies_of_interest.append(self.create_other_body(other_target))
 
-    def add_satellites_to_bodies_of_interest(self) -> None:
+    def add_satellites_to_bodies_of_interest(
+        self, skip_insufficient_data: bool = False
+    ) -> None:
         """
         Automatically add all satellites in the target planetary system to
         :attr:`other_bodies_of_interest`.
@@ -396,6 +415,10 @@ class Body(SpiceBase):
         a code in the range 701 to 798 is added for Uranus.
 
         See also :func:`add_other_bodies_of_interest`.
+
+        Args:
+            skip_insufficient_data: If True, satellites with insufficient data in the
+                SPICE kernel will be skipped. If False, an exception will be raised.
         """
         id_base = (self.target_body_id // 100) * 100
         for other_target in range(id_base + 1, id_base + 99):
@@ -403,6 +426,11 @@ class Body(SpiceBase):
                 self.other_bodies_of_interest.append(
                     self.create_other_body(other_target)
                 )
+            except SpiceSPKINSUFFDATA:
+                if skip_insufficient_data:
+                    continue
+                else:
+                    raise
             except NotFoundError:
                 continue
 
@@ -791,6 +819,38 @@ class Body(SpiceBase):
         """
         return self._radec2km_radians(*self._degree_pair2radians(ra, dec))
 
+    def km2lonlat(self, km_x: float, km_y: float, **kwargs) -> tuple[float, float]:
+        """
+        Convert distance in target plane to longitude/latitude coordinates on the target
+        body.
+
+        Args:
+            km_x: Distance in target plane in km in the East-West direction.
+            km_y: Distance in target plane in km in the North-South direction.
+            **kwargs: Additional arguments are passed to :func:`Body.radec2lonlat`.
+
+        Returns:
+            `(lon, lat)` tuple containing the longitude and latitude of the point. If
+            the provided km coordinates are missing the target body, then the `lon`
+            and `lat` values will both be NaN (see :func:`Body.radec2lonlat`).
+        """
+        return self.radec2lonlat(*self.km2radec(km_x, km_y), **kwargs)
+
+    def lonlat2km(self, lon: float, lat: float) -> tuple[float, float]:
+        """
+        Convert longitude/latitude coordinates on the target body to distances in the
+        target plane.
+
+        Args:
+            lon: Longitude of point on the target body.
+            lat: Latitude of point on the target body.
+
+        Returns:
+            `(km_x, km_y)` tuple containing distances in km in the target plane in the
+            East-West and North-South directions respectively.
+        """
+        return self.radec2km(*self.lonlat2radec(lon, lat))
+
     def _get_matplotlib_radec2km_transform_radians(
         self,
     ) -> matplotlib.transforms.Affine2D:
@@ -1477,6 +1537,9 @@ class Body(SpiceBase):
         color: str | tuple[float, float, float] = 'k',
         label_poles: bool = True,
         add_title: bool = True,
+        grid_interval: float = 30,
+        indicate_equator: bool = False,
+        indicate_prime_meridian: bool = False,
         **kwargs,
     ) -> Axes:
         """Plot generic wireframe representation of the observation"""
@@ -1488,15 +1551,27 @@ class Body(SpiceBase):
         else:
             transform = transform + ax.transData
 
-        for ra, dec in self.visible_lonlat_grid_radec(30):
+        gridline_kwargs = dict(
+            color=color,
+            alpha=0.5,
+            transform=transform,
+            **kwargs,
+        )
+        lons = np.arange(0, 360, grid_interval)
+        for lon, (ra, dec) in zip(lons, self.visible_lon_grid_radec(lons)):
             ax.plot(
                 ra,
                 dec,
-                color=color,
-                linestyle=':',
-                alpha=0.5,
-                transform=transform,
-                **kwargs,
+                linestyle='-' if lon == 0 and indicate_prime_meridian else ':',
+                **gridline_kwargs,
+            )
+        lats = np.arange(-90, 90, grid_interval)
+        for lat, (ra, dec) in zip(lats, self.visible_lat_grid_radec(lats)):
+            ax.plot(
+                ra,
+                dec,
+                linestyle='-' if lat == 0 and indicate_equator else ':',
+                **gridline_kwargs,
             )
 
         ax.plot(
@@ -1594,13 +1669,17 @@ class Body(SpiceBase):
     def plot_wireframe_radec(
         self,
         ax: Axes | None = None,
-        show: bool = False,
         color: str | tuple[float, float, float] = 'k',
+        *,
         label_poles: bool = True,
         add_title: bool = True,
         add_axis_labels: bool = True,
+        grid_interval: float = 30,
+        indicate_equator: bool = False,
+        indicate_prime_meridian: bool = False,
         aspect_adjustable: Literal['box', 'datalim'] = 'datalim',
         dms_ticks: bool = True,
+        show: bool = False,
         **kwargs,
     ) -> Axes:
         """
@@ -1610,15 +1689,19 @@ class Body(SpiceBase):
         Args:
             ax: Matplotlib axis to use for plotting. If `ax` is None (the default), uses
                 `plt.gca()` to get the currently active axis.
-            show: Toggle immediately showing the plotted figure with `plt.show()`.
             color: Matplotlib color used for to plot the wireframe.
             label_poles: Toggle labelling the poles of the target body.
             add_title: Add title generated by :func:`get_description` to the axis.
             add_axis_labels: Add axis labels.
+            grid_interval: Spacing between grid lines in degrees.
+            indicate_equator: Toggle indicating the equator with a solid line.
+            indicate_prime_meridian: Toggle indicating the prime meridian with a solid
+                line.
             aspect_adjustable: Set `adjustable` parameter when setting the aspect ratio.
                 Passed to :func:`matplotlib.axes.Axes.set_aspect`.
             dms_ticks: Toggle between showing ticks as degrees, minutes and seconds
                 (e.g. 12°34′56″) or decimal degrees (e.g. 12.582).
+            show: Toggle immediately showing the plotted figure with `plt.show()`.
             **kwargs: Additional arguments are passed to Matplotlib plotting functions
                 (useful for e.g. specifying `zorder`).
 
@@ -1631,6 +1714,9 @@ class Body(SpiceBase):
             color=color,
             label_poles=label_poles,
             add_title=add_title,
+            grid_interval=grid_interval,
+            indicate_equator=indicate_equator,
+            indicate_prime_meridian=indicate_prime_meridian,
             **kwargs,
         )
 
@@ -1649,12 +1735,16 @@ class Body(SpiceBase):
     def plot_wireframe_km(
         self,
         ax: Axes | None = None,
-        show: bool = False,
         color: str | tuple[float, float, float] = 'k',
+        *,
         label_poles: bool = True,
         add_title: bool = True,
         add_axis_labels: bool = True,
+        grid_interval: float = 30,
+        indicate_equator: bool = False,
+        indicate_prime_meridian: bool = False,
         aspect_adjustable: Literal['box', 'datalim'] = 'datalim',
+        show: bool = False,
         **kwargs,
     ) -> Axes:
         """
@@ -1664,13 +1754,17 @@ class Body(SpiceBase):
         Args:
             ax: Matplotlib axis to use for plotting. If `ax` is None (the default), uses
                 `plt.gca()` to get the currently active axis.
-            show: Toggle immediately showing the plotted figure with `plt.show()`.
             color: Matplotlib color used for to plot the wireframe.
             label_poles: Toggle labelling the poles of the target body.
             add_title: Add title generated by :func:`get_description` to the axis.
             add_axis_labels: Add axis labels.
+            grid_interval: Spacing between grid lines in degrees.
+            indicate_equator: Toggle indicating the equator with a solid line.
+            indicate_prime_meridian: Toggle indicating the prime meridian with a solid
+                line.
             aspect_adjustable: Set `adjustable` parameter when setting the aspect ratio.
                 Passed to :func:`matplotlib.axes.Axes.set_aspect`.
+            show: Toggle immediately showing the plotted figure with `plt.show()`.
             **kwargs: Additional arguments are passed to Matplotlib plotting functions
                 (useful for e.g. specifying `zorder`).
 
@@ -1685,6 +1779,9 @@ class Body(SpiceBase):
             color=color,
             label_poles=label_poles,
             add_title=add_title,
+            grid_interval=grid_interval,
+            indicate_equator=indicate_equator,
+            indicate_prime_meridian=indicate_prime_meridian,
             **kwargs,
         )
         if add_axis_labels:
